==> vtk-6.3.0-5-armv6h.pkg.tar.xz: vtk/vtkMergeTables.java <==
// java wrapper for vtkMergeTables object
//

package vtk;
import vtk.*;

public class vtkMergeTables extends vtkTableAlgorithm
{

  private native String GetClassName_0();
  public String GetClassName()
    { return GetClassName_0(); }

  private native int IsA_1(String id0);
  public int IsA(String id0)
    { return IsA_1(id0); }

  private native void SetFirstTablePrefix_2(String id0);
  public void SetFirstTablePrefix(String id0)
    { SetFirstTablePrefix_2(id0); }

  private native String GetFirstTablePrefix_3();
  public String GetFirstTablePrefix()
    { return GetFirstTablePrefix_3(); }

  private native void SetSecondTablePrefix_4(String id0);
  public void SetSecondTablePrefix(String id0)
    { SetSecondTablePrefix_4(id0); }

  private native String GetSecondTablePrefix_5();
  public String GetSecondTablePrefix()
    { return GetSecondTablePrefix_5(); }

  private native void SetMergeColumnsByName_6(boolean id0);
  public void SetMergeColumnsByName(boolean id0)
    { SetMergeColumnsByName_6(id0); }

  private native boolean GetMergeColumnsByName_7();
  public boolean GetMergeColumnsByName()
    { return GetMergeColumnsByName_7(); }

  private native void MergeColumnsByNameOn_8();
  public void MergeColumnsByNameOn()
    { MergeColumnsByNameOn_8(); }

  private native void MergeColumnsByNameOff_9();
  public void MergeColumnsByNameOff()
    { MergeColumnsByNameOff_9(); }

  private native void SetPrefixAllButMerged_10(boolean id0);
  public void SetPrefixAllButMerged(boolean id0)
    { SetPrefixAllButMerged_10(id0); }

  private native boolean GetPrefixAllButMerged_11();
  public boolean GetPrefixAllButMerged()
    { return GetPrefixAllButMerged_11(); }

  private native void PrefixAllButMergedOn_12();
  public void PrefixAllButMergedOn()
    { PrefixAllButMergedOn_12(); }

  private native void PrefixAllButMergedOff_13();
  public void PrefixAllButMergedOff()
    { PrefixAllButMergedOff_13(); }

  public vtkMergeTables() { super(); }

  public vtkMergeTables(long id) { super(id); }
  public native long   VTKInit();

}

==> vtk-8.2.0-5-armv6h.pkg.tar.xz: vtk/vtkMergeTables.java <==
// java wrapper for vtkMergeTables object
//

package vtk;
import vtk.*;

public class vtkMergeTables extends vtkTableAlgorithm
{

  private native int IsTypeOf_0(String id0);
  public int IsTypeOf(String id0)
    { return IsTypeOf_0(id0); }

  private native int IsA_1(String id0);
  public int IsA(String id0)
    { return IsA_1(id0); }

  private native void SetFirstTablePrefix_2(String id0);
  public void SetFirstTablePrefix(String id0)
    { SetFirstTablePrefix_2(id0); }

  private native String GetFirstTablePrefix_3();
  public String GetFirstTablePrefix()
    { return GetFirstTablePrefix_3(); }

  private native void SetSecondTablePrefix_4(String id0);
  public void SetSecondTablePrefix(String id0)
    { SetSecondTablePrefix_4(id0); }

  private native String GetSecondTablePrefix_5();
  public String GetSecondTablePrefix()
    { return GetSecondTablePrefix_5(); }

  private native void SetMergeColumnsByName_6(boolean id0);
  public void SetMergeColumnsByName(boolean id0)
    { SetMergeColumnsByName_6(id0); }

  private native boolean GetMergeColumnsByName_7();
  public boolean GetMergeColumnsByName()
    { return GetMergeColumnsByName_7(); }

  private native void MergeColumnsByNameOn_8();
  public void MergeColumnsByNameOn()
    { MergeColumnsByNameOn_8(); }

  private native void MergeColumnsByNameOff_9();
  public void MergeColumnsByNameOff()
    { MergeColumnsByNameOff_9(); }

  private native void SetPrefixAllButMerged_10(boolean id0);
  public void SetPrefixAllButMerged(boolean id0)
    { SetPrefixAllButMerged_10(id0); }

  private native boolean GetPrefixAllButMerged_11();
  public boolean GetPrefixAllButMerged()
    { return GetPrefixAllButMerged_11(); }

  private native void PrefixAllButMergedOn_12();
  public void PrefixAllButMergedOn()
    { PrefixAllButMergedOn_12(); }

  private native void PrefixAllButMergedOff_13();
  public void PrefixAllButMergedOff()
    { PrefixAllButMergedOff_13(); }

  public vtkMergeTables() { super(); }

  public vtkMergeTables(long id) { super(id); }
  public native long   VTKInit();

}
